==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/changetextscasedialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "changetextscasedialog.h"

#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qradiobutton.h>
#include <qlayout.h>

#include <klocale.h>

using namespace SubtitleComposer;

ChangeTextsCaseDialog::ChangeTextsCaseDialog( QWidget* parent ):
	TargetableTextsActionDialog( i18n( "Change Case" ), parent )
{
	QGroupBox* caseGroupBox = createGroupBox( i18n( "New case" ) );

	m_lowerRadioButton = new QRadioButton( caseGroupBox );
	m_lowerRadioButton->setText( i18n( "Lower case" ) );
	m_lowerRadioButton->setChecked( true );

	m_upperRadioButton = new QRadioButton( caseGroupBox );
	m_upperRadioButton->setText( i18n( "Upper case" ) );

	m_titleRadioButton = new QRadioButton( caseGroupBox );
	m_titleRadioButton->setText( i18n( "Title case" ) );

	m_sentenceRadioButton = new QRadioButton( caseGroupBox );
	m_sentenceRadioButton->setText( i18n( "Sentence case" ) );

	m_lowerFirstCheckBox = new QCheckBox( caseGroupBox );
	m_lowerFirstCheckBox->setText( i18n( "Change to lower case first" ) );
	m_lowerFirstCheckBox->setEnabled( false );

	createTextsTargetGroupBox();
	createLinesTargetGroupBox();

	QHBoxLayout* lowerFirstLayout = new QHBoxLayout();
	lowerFirstLayout->addSpacing( 20 );
	lowerFirstLayout->addWidget( m_lowerFirstCheckBox );

	QGridLayout* caseLayout = createLayout( caseGroupBox );
	caseLayout->addWidget( m_lowerRadioButton, 0, 0 );
	caseLayout->addWidget( m_upperRadioButton, 1, 0 );
	caseLayout->addWidget( m_titleRadioButton, 2, 0 );
	caseLayout->addWidget( m_sentenceRadioButton, 3, 0 );
	caseLayout->addLayout( lowerFirstLayout, 4, 0 );

	connect( caseGroupBox, SIGNAL( clicked(int) ), this, SLOT( onCaseGroupBoxClicked(int) ) );
}

ChangeTextsCaseDialog::CaseOp ChangeTextsCaseDialog::caseOperation()
{
	if ( m_lowerRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Lower;
	else if ( m_upperRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Upper;
	else if ( m_titleRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Title;
	else // if ( m_sentenceRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Sentence;
}

bool ChangeTextsCaseDialog::lowerFirst()
{
	return m_lowerFirstCheckBox->isChecked();
}

void ChangeTextsCaseDialog::onCaseGroupBoxClicked( int id )
{
	if ( id < 2 )
		m_lowerFirstCheckBox->setChecked( false );
	m_lowerFirstCheckBox->setEnabled( id >= 2 );
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/changetextscasedialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "changetextscasedialog.h"

#include <qcheckbox.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>

#include <klocale.h>

using namespace SubtitleComposer;

ChangeTextsCaseDialog::ChangeTextsCaseDialog( QWidget* parent ):
	ActionWithTargetDialog( i18n( "Change Case" ), parent )
{
	QButtonGroup* caseButtonGroup = createButtonGroup( i18n( "New case" ) );

	m_lowerRadioButton = new QRadioButton( caseButtonGroup );
	m_lowerRadioButton->setText( i18n( "Lower case" ) );
	m_lowerRadioButton->setChecked( true );

	m_upperRadioButton = new QRadioButton( caseButtonGroup );
	m_upperRadioButton->setText( i18n( "Upper case" ) );

	m_titleRadioButton = new QRadioButton( caseButtonGroup );
	m_titleRadioButton->setText( i18n( "Title case" ) );

	m_sentenceRadioButton = new QRadioButton( caseButtonGroup );
	m_sentenceRadioButton->setText( i18n( "Sentence case" ) );

	m_lowerFirstCheckBox = new QCheckBox( caseButtonGroup );
	m_lowerFirstCheckBox->setText( i18n( "Convert to lower case first" ) );
	m_lowerFirstCheckBox->setEnabled( false );


	createLinesTargetButtons();
	createTextsTargetButtons();


	QHBoxLayout* lowerFirstLayout = new QHBoxLayout();
	lowerFirstLayout->addSpacing( 20 );
	lowerFirstLayout->addWidget( m_lowerFirstCheckBox );

	QGridLayout* caseLayout = createLayout( caseButtonGroup );
	caseLayout->addWidget( m_lowerRadioButton, 0, 0 );
	caseLayout->addWidget( m_upperRadioButton, 1, 0 );
	caseLayout->addWidget( m_titleRadioButton, 2, 0 );
	caseLayout->addWidget( m_sentenceRadioButton, 3, 0 );
	caseLayout->addLayout( lowerFirstLayout, 4, 0 );

	connect( caseButtonGroup, SIGNAL( clicked(int) ), this, SLOT( onCaseButtonGroupClicked(int) ) );
}

ChangeTextsCaseDialog::CaseOp ChangeTextsCaseDialog::caseOperation() const
{
	if ( m_lowerRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Lower;
	else if ( m_upperRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Upper;
	else if ( m_titleRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Title;
	else // if ( m_sentenceRadioButton->isChecked() )
		return ChangeTextsCaseDialog::Sentence;
}

bool ChangeTextsCaseDialog::lowerFirst() const
{
	return m_lowerFirstCheckBox->isChecked();
}

void ChangeTextsCaseDialog::onCaseButtonGroupClicked( int id )
{
	if ( id < 2 )
		m_lowerFirstCheckBox->setChecked( false );
	m_lowerFirstCheckBox->setEnabled( id >= 2 );
}
